@@ -224,7 +224,8 @@ class ModelSaverCallback(tf.keras.callbacks.Callback):
     """
     Saves Model at each end of the epoch when the best accuracy/loss is presented.
     """
-    def __init__(self, best_metric=float('inf'), save_root="./", save_metric='val_loss', file_name="my_model", enable=True, epoch=0, include_optimizer=False):
+    def __init__(self, best_metric=float('inf'), save_root="./", save_metric='val_loss',
+                metric_type="loss",file_name="my_model", enable=True, epoch=0, include_optimizer=False):
         """
 
         Args:
@@ -233,6 +234,7 @@ class ModelSaverCallback(tf.keras.callbacks.Callback):
             save_metric (str): One of 'val_loss', 'val_accuracy'
             enable (bool): Set previous epoch number if resuming
             epoch (int): Epoch number
+            metric_type (str): (loss, score)
         """
         super(ModelSaverCallback, self).__init__()
         self.best_metric = best_metric
@@ -245,6 +247,7 @@ class ModelSaverCallback(tf.keras.callbacks.Callback):
         self.save_metric = save_metric
         self.file_name = file_name
         self.include_optimizer = include_optimizer
+        self.metric_type = metric_type
 
     def on_epoch_end(self, epoch, logs=None):
         try:
@@ -252,13 +255,13 @@ class ModelSaverCallback(tf.keras.callbacks.Callback):
             a = logs[self.save_metric]
             b = self.best_metric
 
-            if self.save_metric.find("accuracy") > 0:
+            if self.metric_type == "score":
                 a, b = b, a
 
             if a < b:
                 p_file_list = glob.glob("{}/*.h5".format(self.save_root))
                 p_file_list = sorted(p_file_list, key=lambda x: x[-10:])
-                if self.save_metric.find("accuracy") < 0:
+                if self.metric_type == "loss":
                     p_file_list = p_file_list[::-1]
 
                 for i, file_path in enumerate(p_file_list):
@@ -416,7 +419,7 @@ def wait_ctrl_c(pre_msg="Press Ctrl+c to quit Tensorboard", post_msg="\nExit."):
 def get_tf_callbacks(root,
                      tboard_callback=True, tboard_update_freq='epoch', tboard_histogram_freq=1, tboard_profile_batch=0,
                      confuse_callback=True, label_info=None, x_test=None, y_test=None, test_generator_=None, test_dataset=None, figure_size=(12, 10), model_out_idx=-1,
-                     modelsaver_callback=False, best_loss=float('inf'), save_root=None, best_epoch=0, save_metric='val_loss', save_file_name="my_model",
+                     modelsaver_callback=False, best_loss=float('inf'), save_root=None, best_epoch=0, save_metric='val_loss', save_file_name="my_model", metric_type="loss",
                      earlystop_callback=True, earlystop_monitor='val_loss', earlystop_patience=0, earlystop_restore_weights=True,
                      sparsity_callback=False, sparsity_threshold=0.05):
     """
@@ -491,7 +494,7 @@ def get_tf_callbacks(root,
         if not save_root:
             save_root = log_root_
         callbacks_.append(
-            ModelSaverCallback(best_metric=best_loss, save_root=save_root, epoch=best_epoch, save_metric=save_metric, file_name=save_file_name)
+            ModelSaverCallback(best_metric=best_loss, save_root=save_root, epoch=best_epoch, save_metric=save_metric, file_name=save_file_name, metric_type=metric_type)
         )
 
     if earlystop_callback:
